@@ -1,3 +1,6 @@
+#ifndef INCLUDED_UINPUT_H_
+#define INCLUDED_UINPUT_H_
+
 #include <iostream>
 #include <deque>
 #include <queue>
@@ -31,13 +34,11 @@ class UInput
         size_t idx() const;
         size_t lineNr() const;
         size_t lineOffset();
-//OBS        void inc(size_t value);
         std::string const &line() const;
         size_t nPending() const;
         void setPending(size_t size);
         void close();                   // force closing the stream
         void toEOF();                   // move the stream to its EOF pos.
-// OBS        void zero();
 
     private:
         size_t next();
@@ -46,3 +47,5 @@ class UInput
 
 #include "uinput.f"
 
+
+#endif
